package com.ibm.commerce.validation.commands;

//*-------------------------------------------------------------------
//* Licensed Materials - Property of IBM
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* US Government Users Restricted Rights - Use, duplication or
//* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//*
//*-------------------------------------------------------------------
//*
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability,
//* serviceability or functionality.
//*
//*-------------------------------------------------------------------

import java.util.*;
import com.ibm.commerce.exception.*;
import com.ibm.commerce.ras.*;
import com.ibm.commerce.server.*;
import com.ibm.commerce.datatype.*;
import com.ibm.commerce.usermanagement.commands.*;
import com.ibm.commerce.validation.objects.*;
import com.ibm.commerce.validation.constants.*;

/**
 * This class is called by the create address logic to validate the zipcode information
 * entered in the address.  This class needs to be registered in the CMDREG table to 
 * get it to run instead of the default AuditAddressCmdImpl
 */
public class AuditZipcodeCmdImpl extends AuditAddressCmdImpl implements AuditAddressCmd {

public final static String CLASSNAME = "com.ibm.commerce.validation.commands.AuditZipcodeCmdImpl";

public AuditZipcodeCmdImpl() { 
}

public void performExecute() throws ECException {
	final String METHODNAME = "performExecute";

	super.performExecute();

	String city = requestProperties.getString(ECUserConstants.EC_ADDR_CITY, null);
	String country = requestProperties.getString(ECUserConstants.EC_ADDR_COUNTRY, null);
	String state = requestProperties.getString(ECUserConstants.EC_ADDR_STATE, null);
	String zipcode = requestProperties.getString(ECUserConstants.EC_ADDR_ZIPCODE, null);

	// the database should have all values stored in uppercase
	try {
		city = city.trim().toUpperCase();
		state = state.trim().toUpperCase();
		country = country.trim().toUpperCase();
		zipcode = zipcode.trim().toUpperCase();
	} catch (NullPointerException e) {
		// these parameter shouldn't be null since there's other code that checks for this
		// before this method is called
		throw new ECSystemException(ECMessage._ERR_NULL_EXCEPTION, CLASSNAME, 
			METHODNAME, ECMessageHelper.generateMsgParms(e.getMessage()));
	}
	
	try { 
		// The zipcode validation table has a primary key of zipcode,city so that you
		// can have multiple cities/towns as having the same zipcode.  The zipcode
		// check is pretty basic here.  It does a lookup based on the zipcode,city and
		// then retrieves the state and country info to compare that with the entries
		// the user entered.  If they match then the zipcode is valid.
		// If a more complex logic is needed then it should be entered here.
		ZipcodeValidationAccessBean code = new ZipcodeValidationAccessBean();
		code.setInitKey_zipcode(zipcode);
		code.setInitKey_city(city);
		code.refreshCopyHelper();
		
		String storedCountry = code.getCountry().trim().toUpperCase();
		String storedState = code.getState().trim().toUpperCase();
	
		if (!storedState.equals(state) || !storedCountry.equals(country)) {
			// since the state and country don't seem to match we need to throw a custom
			// error code back to the VIEW JSP to display the error message.  This is 
			// done via the ECApplicationException and using the ValidationContstants error
			// codes
			ibResult = false;
			TypedProperty exceptionProperties = new TypedProperty();
			exceptionProperties.put(ECConstants.EC_ERROR_CODE, ValidationConstants.INVALID_ZIPCODE);
			throw new ECApplicationException(ECMessage._ERR_CMD_INVALID_PARAM, CLASSNAME, METHODNAME,
				ECMessageHelper.generateMsgParms(ValidationConstants.INVALID_ZIPCODE),
				istrErrorViewName, exceptionProperties);
		}
	} catch (javax.ejb.FinderException e) {
		// since the zipcode and city were not found we need to throw a custom
		// error code back to the VIEW JSP to display the error message.  This is 
		// done via the ECApplicationException and using the ValidationContstants error
		// codes
		ibResult = false;
		TypedProperty exceptionProperties = new TypedProperty();
		exceptionProperties.put(ECConstants.EC_ERROR_CODE, ValidationConstants.INVALID_ZIPCODE);
		throw new ECApplicationException(ECMessage._ERR_CMD_INVALID_PARAM, CLASSNAME, METHODNAME,
			ECMessageHelper.generateMsgParms(ValidationConstants.INVALID_ZIPCODE),
			istrErrorViewName, exceptionProperties);
	} catch (java.rmi.RemoteException e) {
		throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION, CLASSNAME, 
			METHODNAME, ECMessageHelper.generateMsgParms(e.getMessage()));
	} catch (javax.naming.NamingException e) {
		throw new ECSystemException(ECMessage._ERR_NAMING_EXCEPTION, CLASSNAME, 
			METHODNAME, ECMessageHelper.generateMsgParms(e.getMessage()));
	} catch (javax.ejb.CreateException e) {
		throw new ECSystemException(ECMessage._ERR_NAMING_EXCEPTION, CLASSNAME,
			METHODNAME, ECMessageHelper.generateMsgParms(e.getMessage()));
	}

	ibResult = true;
}

}
