//*-------------------------------------------------------------------
//* Licensed Materials - Property of IBM
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* US Government Users Restricted Rights - Use, duplication or
//* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//*
//*-------------------------------------------------------------------
//*
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability,
//* serviceability or functionality.
//*
//*-------------------------------------------------------------------

package com.mycompany.membergroup.commands;

import com.ibm.commerce.condition.ConditionUtil;
import com.ibm.commerce.condition.SimpleCondition;
import com.ibm.commerce.membergroup.commands.CheckUserInMemberGroupCmdImpl;
import com.ibm.ivj.ejb.runtime.AbstractAccessBean;
import com.mycompany.ejbs.BeverageHome;
import com.mycompany.ejbs.Beverage;
import javax.rmi.PortableRemoteObject;

/**
 * This class implements the CheckUserInMemberGroupCmd interface to
 * provide the task command that checks if a specified user belongs to a specified member group.
 */
public class MyCheckUserInMemberGroupCmdImpl extends CheckUserInMemberGroupCmdImpl
 {
  /**
   * Home interface for the beverage bean.
   */
  public static BeverageHome _beverageHome;

  /**
   * Evaluate a simple condition.  Simple conditions are persisted in XML format as follows:
   * <code><br>
   * &LT;simpleCondition><br>
   *   &LT;variable name="gender"/><br>
   *   &LT;operator name="="/><br>
   *   &LT;value data="M"/><br>
   * &LT;/simpleCondition><br>
   * </code>
   *
   * @param variable  The name of the variable.
   * @param operator  The name of the operator.
   * @param value  The data for the value.
   * @param qualifires  An array of qualifiers.
   *
   * @return  <code>true</code> if the condition evaluates to true.
   */
  public boolean evaluate(String variable, String operator, String value, SimpleCondition.Qualifier[] qualifiers)
   {
    boolean result = false;

    if ("beverage".equals(variable))
     {
      result = evaluateBeverageCondition(operator, value, qualifiers);
     }
    else
     {
      result = super.evaluate(variable, operator, value, qualifiers);
     }
    return result;
   }

  /**
   * Evaluate the "beverage" condition.
   *
   * @param operator  The name of the operator.
   * @param value  The data for the value.
   * @param qualifiers  An array of qualifiers.
   *
   * @return  <code>true</code> if the condition evaluates to true.
   */
  protected boolean evaluateBeverageCondition(String operator, String value, SimpleCondition.Qualifier[] qualifiers)
   {
    return ConditionUtil.evaluateString(getBeverage(), operator, value);
   }

  /**
   * Get the beverage for the specified user.
   */
  protected String getBeverage()
   {
    String beverage = null;
    if (_beverageHome == null)
     {
      String nameServiceURL = System.getProperty("java.naming.provider.url");
      if (nameServiceURL == null)
       {
        nameServiceURL = "iiop:///";
       }
      String nameServiceFactory = System.getProperty("java.naming.factory.initial");
      if (nameServiceFactory == null)
       {
        nameServiceFactory = "java.naming.provider.url";
       }
      try
       {
        _beverageHome = (BeverageHome) PortableRemoteObject.narrow(AbstractAccessBean.getGlobalHome(nameServiceURL, nameServiceFactory, "Beverage"), BeverageHome.class);
       }
      catch (Exception e)
       {
       }
      if (_beverageHome == null)
       {
        System.out.println("BeverageHome interface could not be found");
       }
     }
    if (_beverageHome != null)
     {
      try
       {
        Beverage beverageBean = _beverageHome.findByUsersId(_user.getUserIdInEJBType());
        beverage = beverageBean.getBeverage();
       }
      catch (Exception e)
       {
       }
     }
    return beverage;
   }
 }
