//*-------------------------------------------------------------------
//* Licensed Materials - Property of IBM
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* US Government Users Restricted Rights - Use, duplication or
//* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//*
//*-------------------------------------------------------------------
//*
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability,
//* serviceability or functionality.
//*
//*-------------------------------------------------------------------

package com.mycompany.tools.segmentation;

import com.ibm.commerce.condition.Condition;
import com.ibm.commerce.condition.SimpleCondition;
import com.ibm.commerce.tools.segmentation.SegmentNotebookDataBean;
import com.ibm.commerce.tools.segmentation.SegmentUtil;
import java.util.Vector;

/**
 * This class extends the SegmentNotebookDataBean class to
 * create the notebook databean for a customer segment.
 */
public class MySegmentNotebookDataBean extends SegmentNotebookDataBean
 {
  /**
   * Beverage operator.
   */
  protected String _beverageOp = VALUE_DO_NOT_USE;

  /**
   * A vector of beverage values.
   */
  protected Vector _beverageValues = new Vector();

  /**
   * Gets the beverage operator.
   *
   * @return The beverage operator.
   */
  public String getBeverageOp()
   {
    return _beverageOp;
   }

  /**
   * Gets the beverage values.
   *
   * @return The beverage values.
   */
  public Vector getBeverageValues()
   {
    return _beverageValues;
   }

  /**
   * Load a simple condition.
   *
   * @param simpleCondition A SimpleCondition object.
   * @param parent          The parent condition object.
   */
  protected void loadSimpleCondition(SimpleCondition simpleCondition, Condition parent)
   {
    String variable = simpleCondition.getVariable();
    String op = simpleCondition.getOperator();
    String value = simpleCondition.getValue();

    if ("beverage".equals(variable))
     {
      _beverageOp = VALUE_ONE_OF;
      _beverageValues.addElement(value);
     }
    else
     {
      super.loadSimpleCondition(simpleCondition, parent);
     }
   }

  /**
   * Populate the databean.
   */
  public void populate() throws Exception
   {
    super.populate();
    if (_xml != null)
     {
      _beverageOp = (String)_xml.get("beverageOp");
      _beverageValues = SegmentUtil.toVector(_xml.get("beverageValues"));
     }
   }
 }
